@@ -6,12 +6,12 @@
 ( cd opt/kde/share/doc/HTML/fr/kdm ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kig ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kig ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kpf ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/ktuberling ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/ktuberling ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/amor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/amor ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/karm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/karm ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kate ; rm -rf common )
@@ -62,6 +62,12 @@
 ( cd opt/kde/share/doc/HTML/fr/ksysguard ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kbounce ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kbounce ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kdearch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kdearch ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kdelirc/kcmlirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kdelirc/irkick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kbattleship ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kaboodle ; rm -rf common )
@@ -96,8 +102,6 @@
 ( cd opt/kde/share/doc/HTML/fr/kjots ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kmail ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kmail ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kmidi ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kmidi ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kmoon ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/knode ; rm -rf common )
@@ -132,6 +136,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kmousetool ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/klinkstatus ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kompare ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kontact ; rm -rf common )
@@ -164,8 +170,8 @@
 ( cd opt/kde/share/doc/HTML/fr/konquest ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/panelappearance ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/panelappearance ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kturtle ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kverbos ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kwallet ; rm -rf common )
@@ -184,8 +190,6 @@
 ( cd opt/kde/share/doc/HTML/fr/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kioslave ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/flashkard ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/flashkard ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kaddressbook ; rm -rf common )
@@ -334,6 +338,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/passwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kcontrol/panelappearance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/ebrowsing ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/background ; rm -rf common )
@@ -360,8 +366,6 @@
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/laptop ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kcontrol/kxmlrpcd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kcontrol/kxmlrpcd ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmnotify ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmsmserver ; rm -rf common )
@@ -452,12 +456,8 @@
 ( cd opt/kde/share/doc/HTML/fr/knotes ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kpager ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kpaint ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kpaint ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kopete ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kopete ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kpilot ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kpilot ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kpoker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kpoker ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kruler ; rm -rf common )
@@ -488,6 +488,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kblackbox ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kcharselect ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/quanta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/quanta ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kuickshow ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kiconedit ; rm -rf common )
@@ -502,12 +504,12 @@
 ( cd opt/kde/share/doc/HTML/fr/klickety ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kleopatra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kleopatra ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kenolaba ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kgpgcertmanager ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kworldclock ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/KRegExpEditor ; rm -rf common )
